package com.dky.calculate;


public class Overall {

    /**
     * 初次投资费用（万元）
     * @param yearOut 预计年产量
     * @param madeHours 单台电设备制造一批产品的周期小时
     * @param proOut 单台电设备制造一批产品的产量
     * @param runHours 单台设备年运行时间
     * @param devicePrice 单台电设备价格
     * @return
     */
    public Double investment(Double yearOut,
                             Integer madeHours,
                             Integer proOut,
                             Integer runHours,
                             Double devicePrice){
        double d1 = yearOut * madeHours;
        double d2 = proOut * runHours;
        int remainder = (int)(d1/d2) + (d1%d2==0?0:1);
        return remainder * devicePrice;
    }

    /**
     * 年运行费用（万元）
     * @param deviceNum 电设备设备台数
     * @param devicePower 单台电设备的功率
     * @param days 电设备年运行时间
     * @param laborCost 电替代设备人工费用成本
     * @return
     */
    public Double getRunCost(Integer deviceNum,
                             Double devicePower,
                             Integer days,
                             Double laborCost){
        return deviceNum * devicePower * days  * 0.5 + laborCost;
    }

    /**
     * 年总费用（万元）
     * @param deviceNum 电设备设备台数
     * @param devicePrice 单台电设备价格
     * @param useYears 使用年限
     * @param devicePower 单台电设备的功率
     * @param days 电设备年运行时间(天)
     * @param laborCost 电替代设备人工费用成本
     * @return
     */
    public Double getYearCost(Integer deviceNum,
                              Double devicePrice,
                              Integer useYears,
                              Double devicePower,
                              Integer days,
                              Double laborCost){
        double run = deviceNum * devicePower * days  * 0.5 + laborCost;
        return ((deviceNum * devicePrice) / useYears) + run;
    }

    /**
     * 年减碳
     * @param lastYearFee 上年运行费用（万元）
     * @param oldDaborCost 原设备的人工费用（万元）
     * @param deviceNum 电锅炉设备台数
     * @param devicePower 单台电锅炉的功率
     * @param days 年采暖（供冷）时间(天)
     * @return
     */
    public Double calculateAnnualCarbonReduction(Double lastYearFee,
                                                 Double oldDaborCost,
                                                 Integer deviceNum,
                                                 Double devicePower,
                                                 Integer days){
        double d1 = (((lastYearFee - oldDaborCost) / 0.9) * 0.7143);
        double d2 = deviceNum * devicePower * days ;
        return  (d1 - (d2 * 0.1229)) * 1.9003;
    }

    /**
     * 替代电量（千瓦时）
     * @param deviceNum 电锅炉设备台数
     * @param devicePower 单台电锅炉的功率
     * @param days 年采暖（供冷）时间(天)
     * @return
     */
    public Double getElectric(Integer deviceNum,
                              Double devicePower,
                              Integer days){
        return deviceNum * devicePower * days  ;
    }
}
